==> zio-aws-sagemaker_2.12-6.20.120.1-sources.jar: zio/aws/sagemaker/model/OnlineStoreConfig.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class OnlineStoreConfig(
    securityConfig: Optional[
      zio.aws.sagemaker.model.OnlineStoreSecurityConfig
    ] = Optional.Absent,
    enableOnlineStore: Optional[Boolean] = Optional.Absent,
    ttlDuration: Optional[zio.aws.sagemaker.model.TtlDuration] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.OnlineStoreConfig = {
    import OnlineStoreConfig.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.OnlineStoreConfig
      .builder()
      .optionallyWith(securityConfig.map(value => value.buildAwsValue()))(
        _.securityConfig
      )
      .optionallyWith(enableOnlineStore.map(value => value: java.lang.Boolean))(
        _.enableOnlineStore
      )
      .optionallyWith(ttlDuration.map(value => value.buildAwsValue()))(
        _.ttlDuration
      )
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.OnlineStoreConfig.ReadOnly =
    zio.aws.sagemaker.model.OnlineStoreConfig.wrap(buildAwsValue())
}
object OnlineStoreConfig {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.OnlineStoreConfig
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.OnlineStoreConfig =
      zio.aws.sagemaker.model.OnlineStoreConfig(
        securityConfig.map(value => value.asEditable),
        enableOnlineStore.map(value => value),
        ttlDuration.map(value => value.asEditable)
      )
    def securityConfig
        : Optional[zio.aws.sagemaker.model.OnlineStoreSecurityConfig.ReadOnly]
    def enableOnlineStore: Optional[Boolean]
    def ttlDuration: Optional[zio.aws.sagemaker.model.TtlDuration.ReadOnly]
    def getSecurityConfig: ZIO[
      Any,
      AwsError,
      zio.aws.sagemaker.model.OnlineStoreSecurityConfig.ReadOnly
    ] = AwsError.unwrapOptionField("securityConfig", securityConfig)
    def getEnableOnlineStore: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("enableOnlineStore", enableOnlineStore)
    def getTtlDuration
        : ZIO[Any, AwsError, zio.aws.sagemaker.model.TtlDuration.ReadOnly] =
      AwsError.unwrapOptionField("ttlDuration", ttlDuration)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.OnlineStoreConfig
  ) extends zio.aws.sagemaker.model.OnlineStoreConfig.ReadOnly {
    override val securityConfig
        : Optional[zio.aws.sagemaker.model.OnlineStoreSecurityConfig.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.securityConfig())
        .map(value =>
          zio.aws.sagemaker.model.OnlineStoreSecurityConfig.wrap(value)
        )
    override val enableOnlineStore: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.enableOnlineStore())
      .map(value => value: Boolean)
    override val ttlDuration
        : Optional[zio.aws.sagemaker.model.TtlDuration.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.ttlDuration())
        .map(value => zio.aws.sagemaker.model.TtlDuration.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.OnlineStoreConfig
  ): zio.aws.sagemaker.model.OnlineStoreConfig.ReadOnly = new Wrapper(impl)
}

==> zio-aws-sagemaker_2.12-7.21.15.3-sources.jar: zio/aws/sagemaker/model/OnlineStoreConfig.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class OnlineStoreConfig(
    securityConfig: Optional[
      zio.aws.sagemaker.model.OnlineStoreSecurityConfig
    ] = Optional.Absent,
    enableOnlineStore: Optional[Boolean] = Optional.Absent,
    ttlDuration: Optional[zio.aws.sagemaker.model.TtlDuration] =
      Optional.Absent,
    storageType: Optional[zio.aws.sagemaker.model.StorageType] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.OnlineStoreConfig = {
    import OnlineStoreConfig.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.OnlineStoreConfig
      .builder()
      .optionallyWith(securityConfig.map(value => value.buildAwsValue()))(
        _.securityConfig
      )
      .optionallyWith(enableOnlineStore.map(value => value: java.lang.Boolean))(
        _.enableOnlineStore
      )
      .optionallyWith(ttlDuration.map(value => value.buildAwsValue()))(
        _.ttlDuration
      )
      .optionallyWith(storageType.map(value => value.unwrap))(_.storageType)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.OnlineStoreConfig.ReadOnly =
    zio.aws.sagemaker.model.OnlineStoreConfig.wrap(buildAwsValue())
}
object OnlineStoreConfig {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.OnlineStoreConfig
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.OnlineStoreConfig =
      zio.aws.sagemaker.model.OnlineStoreConfig(
        securityConfig.map(value => value.asEditable),
        enableOnlineStore.map(value => value),
        ttlDuration.map(value => value.asEditable),
        storageType.map(value => value)
      )
    def securityConfig
        : Optional[zio.aws.sagemaker.model.OnlineStoreSecurityConfig.ReadOnly]
    def enableOnlineStore: Optional[Boolean]
    def ttlDuration: Optional[zio.aws.sagemaker.model.TtlDuration.ReadOnly]
    def storageType: Optional[zio.aws.sagemaker.model.StorageType]
    def getSecurityConfig: ZIO[
      Any,
      AwsError,
      zio.aws.sagemaker.model.OnlineStoreSecurityConfig.ReadOnly
    ] = AwsError.unwrapOptionField("securityConfig", securityConfig)
    def getEnableOnlineStore: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("enableOnlineStore", enableOnlineStore)
    def getTtlDuration
        : ZIO[Any, AwsError, zio.aws.sagemaker.model.TtlDuration.ReadOnly] =
      AwsError.unwrapOptionField("ttlDuration", ttlDuration)
    def getStorageType
        : ZIO[Any, AwsError, zio.aws.sagemaker.model.StorageType] =
      AwsError.unwrapOptionField("storageType", storageType)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.OnlineStoreConfig
  ) extends zio.aws.sagemaker.model.OnlineStoreConfig.ReadOnly {
    override val securityConfig
        : Optional[zio.aws.sagemaker.model.OnlineStoreSecurityConfig.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.securityConfig())
        .map(value =>
          zio.aws.sagemaker.model.OnlineStoreSecurityConfig.wrap(value)
        )
    override val enableOnlineStore: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.enableOnlineStore())
      .map(value => value: Boolean)
    override val ttlDuration
        : Optional[zio.aws.sagemaker.model.TtlDuration.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.ttlDuration())
        .map(value => zio.aws.sagemaker.model.TtlDuration.wrap(value))
    override val storageType: Optional[zio.aws.sagemaker.model.StorageType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.storageType())
        .map(value => zio.aws.sagemaker.model.StorageType.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.OnlineStoreConfig
  ): zio.aws.sagemaker.model.OnlineStoreConfig.ReadOnly = new Wrapper(impl)
}
